==> nextcloud-13.0.1.tgz: nextcloud/settings/l10n/af.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} het u wagwoord verander",
    "You changed your password" : "U het u wagwoord verander",
    "Your password was reset by an administrator" : "U wagwoord is deur ’n administrateur herstel",
    "{actor} changed your email address" : "{actor} het u e-posadres verander",
    "You changed your email address" : "U het u e-posadres verander",
    "Your email address was changed by an administrator" : "U e-posadres is deur ’n administrateur verander",
    "Security" : "Sekuriteit",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "U <strong>wagwoord</strong> of <strong>e-pos</strong> is gewysig",
    "Your apps" : "U toeps",
    "Enabled apps" : "Geaktiveerde toeps",
    "Disabled apps" : "Gedeaktiveerde toeps",
    "App bundles" : "Toepbundels",
    "Wrong password" : "Verkeerde wagwoord",
    "Saved" : "Bewaar",
    "Group already exists." : "Groep bestaan reeds.",
    "Well done, %s!" : "Welgedaan %s!",
    "by %s" : "deur %s",
    "%s-licensed" : "%s-gelisensieer",
    "Documentation:" : "Dokumentasie:",
    "User documentation" : "Gebruikerdokumentasie",
    "Admin documentation" : "Admindokumentasie",
    "Visit website" : "Besoek webwerf",
    "Common Name" : "Algemene Naam",
    "Valid until" : "Geldig tot",
    "Issued By" : "Uitgereik deur",
    "Valid until %s" : "Geldig tot %s",
    "Administrator documentation" : "Administrateurdokumentasie",
    "Online documentation" : "Aanlyndokumentasie",
    "Forum" : "Forum",
    "days" : "dae",
    "Tips & tricks" : "Wenke & truuks",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "U gebruik <strong>%s</strong> van <strong>%s</strong>",
    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "U gebruik <strong>%s</strong> van <strong>%s</strong> (<strong>%s %%</strong>)",
    "Profile picture" : "Profielprent",
    "Upload new" : "Laai nuwe op",
    "Select from Files" : "Kies uit Lêers",
    "Remove image" : "Verwyder beeld",
    "png or jpg, max. 20 MB" : "png of jpg, maks. 20 MB",
    "Cancel" : "Kanselleer",
    "Choose as profile picture" : "Kies as profielprent",
    "Full name" : "Volle naam",
    "Email" : "E-pos",
    "Your email address" : "U e-posadres",
    "No email address set" : "Geen e-posadres ingestel",
    "For password reset and notifications" : "Vir wagwoordherstel en kennisgewings",
    "Phone number" : "Foonnommer",
    "Your phone number" : "U foonnommer",
    "Address" : "Adres",
    "Your postal address" : "U posadres",
    "Website" : "Webwerf",
    "Link https://…" : "Skakel https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter-handvatsel @…",
    "You are member of the following groups:" : "U is ’n lid van die volgende groepe:",
    "Language" : "Taal",
    "Help translate" : "Help met vertaling",
    "Password" : "Wagwoord",
    "Current password" : "Huidige wagwoord",
    "New password" : "Nuwe wagwoord",
    "Change password" : "Verander wagwoord",
    "Device" : "Toestel",
    "App name" : "Toepnaam",
    "Create new app password" : "Skep nuwe toepwagwoord",
    "Username" : "Gebruikersnaam",
    "Settings" : "Instellings",
    "Everyone" : "Almal",
    "Default quota" : "Verstekkwota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Voer asb. ’n verstekkwota in (bv.: “512 MB” of “12 GB”)",
    "Other" : "Ander",
    "Group admin for" : "Groepadmin vir",
    "Quota" : "Kwota",
    "Last login" : "Laaste aantekening",
    "E-Mail" : "E-pos",
    "change full name" : "verander volle naam",
    "set new password" : "stel nuwe wagwoord",
    "change email address" : "verander e-posadres",
    "Default" : "Verstek",
    "Show email address" : "Toon e-posadres",
    "Send email to new user" : "Stuur e-pos aan nuwe gebruiker",
    "Create" : "Skep"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/settings/l10n/af.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} het u wagwoord verander",
    "You changed your password" : "U het u wagwoord verander",
    "Your password was reset by an administrator" : "U wagwoord is deur ’n administrateur herstel",
    "{actor} changed your email address" : "{actor} het u e-posadres verander",
    "You changed your email address" : "U het u e-posadres verander",
    "Your email address was changed by an administrator" : "U e-posadres is deur ’n administrateur verander",
    "Security" : "Sekuriteit",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "U <strong>wagwoord</strong> of <strong>e-pos</strong> is gewysig",
    "Wrong password" : "Verkeerde wagwoord",
    "Saved" : "Bewaar",
    "No user supplied" : "Geen gebruiker verskaf nie",
    "Well done, %s!" : "Welgedaan %s!",
    "Settings saved" : "Instellings gestoor",
    "Go to %s" : "Gaan na %s",
    "Visit website" : "Besoek webwerf",
    "User documentation" : "Gebruikerdokumentasie",
    "Settings" : "Instellings",
    "Email" : "E-pos",
    "Group admin for" : "Groepadmin vir",
    "Language" : "Taal",
    "Default quota" : "Verstekkwota",
    "Your apps" : "U toeps",
    "Disabled apps" : "Gedeaktiveerde toeps",
    "Updates" : "Bywerkings",
    "App bundles" : "Toepbundels",
    "Everyone" : "Almal",
    "Common Name" : "Algemene Naam",
    "Valid until" : "Geldig tot",
    "Issued By" : "Uitgereik deur",
    "Valid until %s" : "Geldig tot %s",
    "Administrator documentation" : "Administrateurdokumentasie",
    "Forum" : "Forum",
    "days" : "dae",
    "Profile picture" : "Profielprent",
    "Upload new" : "Laai nuwe op",
    "Select from Files" : "Kies uit Lêers",
    "Remove image" : "Verwyder beeld",
    "png or jpg, max. 20 MB" : "png of jpg, maks. 20 MB",
    "Cancel" : "Kanselleer",
    "Choose as profile picture" : "Kies as profielprent",
    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "U gebruik <strong>%s</strong> van <strong>%s</strong> (<strong>%s %%</strong>)",
    "Full name" : "Volle naam",
    "Your email address" : "U e-posadres",
    "No email address set" : "Geen e-posadres ingestel",
    "For password reset and notifications" : "Vir wagwoordherstel en kennisgewings",
    "Phone number" : "Foonnommer",
    "Your phone number" : "U foonnommer",
    "Address" : "Adres",
    "Your postal address" : "U posadres",
    "Website" : "Webwerf",
    "Link https://…" : "Skakel https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter-handvatsel @…",
    "Help translate" : "Help met vertaling",
    "Password" : "Wagwoord",
    "Current password" : "Huidige wagwoord",
    "New password" : "Nuwe wagwoord",
    "Change password" : "Verander wagwoord",
    "Device" : "Toestel",
    "App name" : "Toepnaam",
    "Create new app password" : "Skep nuwe toepwagwoord",
    "Username" : "Gebruikersnaam",
    "Enabled apps" : "Geaktiveerde toeps",
    "Group already exists." : "Groep bestaan reeds.",
    "Forbidden" : "Verbode",
    "Invalid user" : "Ongeldige gebruiker",
    "Email saved" : "E-pos gestoor",
    "Tips & tricks" : "Wenke & truuks",
    "by %s" : "deur %s",
    "%s-licensed" : "%s-gelisensieer",
    "Documentation:" : "Dokumentasie:",
    "Admin documentation" : "Admindokumentasie",
    "Online documentation" : "Aanlyndokumentasie",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "U gebruik <strong>%s</strong> van <strong>%s</strong>",
    "You are member of the following groups:" : "U is ’n lid van die volgende groepe:",
    "Show email address" : "Toon e-posadres",
    "Send email to new user" : "Stuur e-pos aan nuwe gebruiker",
    "E-Mail" : "E-pos",
    "Create" : "Skep",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Voer asb. ’n verstekkwota in (bv.: “512 MB” of “12 GB”)",
    "Other" : "Ander",
    "Quota" : "Kwota",
    "Last login" : "Laaste aantekening",
    "change full name" : "verander volle naam",
    "set new password" : "stel nuwe wagwoord",
    "change email address" : "verander e-posadres",
    "Default" : "Verstek"
},
"nplurals=2; plural=(n != 1);");
